# -*- coding: utf-8 -*-
##
##    Lightwatch: Start Skysensor software
##                Monitor output for USB-Errors
##                Reboot System to continue measurements.
##
##    Requirements: Windows XP,NT,2000 (for Skysensor)
##                1. python 2.5 or higher (older python will most likely also work)
##                2. autologin must be enabled (no login screen on startup)
##                3. a link to this file (Lightwatch.py) must be put in the
##                   "Autostart" folder to make sure measurments continue after
##                   the reboot initiated by this script in case of an USB error.
##
##    GW; 8. Jänner 2009
##    19 Jan 2009: reboot if number of lines in data file stays constant
##                 for given time-intervall;
##                 reboot in any case before leaving script and on error; GW.
##
import os,time

Dir=os.getcwd()
Dir=Dir+"\\"

start_skysensor = True

#  time-intervall for check of data file for "USB"-errors
check_intervall_seconds         = 111    # > 100s recommended
#  time-intervall for reboot if number of lines in data-file stays constant
number_of_lines_timeout_seconds = 2* check_intervall_seconds  # put > 100s and larger check_intervall_seconds 

def get_sensorfile_name():
    """ Creates current data-file name of skysensor software
    convention: YYYYMMDD.txt.
    """
    LMT=time.localtime()
    sensorfile=str(LMT[0])
    if LMT[1] <10: sensorfile=sensorfile+"0"+str(LMT[1])
    else:          sensorfile=sensorfile    +str(LMT[1])
    if LMT[2] <10: sensorfile=sensorfile+"0"+str(LMT[2])
    else:          sensorfile=sensorfile    +str(LMT[2])
    sensorfile=sensorfile+".txt"
    return sensorfile

print "\nLightwatch 1.2: start ""Skysensor"", watch output and reboot system on error.\n"
print "Operating in directory:\n", Dir, "\n"
print "Check-intervall:     ", check_intervall_seconds         ,"s."
print "Data-growth-timeout: ", number_of_lines_timeout_seconds ,"s.\n"

print "Important: A link to 'Lightwatch.py' must be put into your 'Autostart'-"
print "folder in the ""programm""-menu and auto-login must be enabled to make sure "
print "that measurements continue after reboot.\n"
print "Good light!\n"

print "Starting Skysensor\n"

if start_skysensor: os.spawnl(os.P_NOWAIT,"Skysensor.exe")

counts=1
status=1
len_lines_old=0
time_last_new_lines=time.time()

try:
    # loop while all looks fine; reboot if not OK
    while counts != 0 and status != 0 \
        and time.time()-time_last_new_lines < number_of_lines_timeout_seconds:

        time.sleep(check_intervall_seconds)

        #__________________________________________ check data and status
        sensor_file_name=get_sensorfile_name()
        if os.access(Dir+sensor_file_name,os.F_OK):
        
            f=file(Dir+sensor_file_name)
            lines=f.readlines()
            f.close()
            # _______________________________________ check counts and status
            counts=int(lines[-1].split()[-2])
            status=int(lines[-1].split()[-1])
            T=time.localtime()
            if T[4]<10: min="0"+str(T[4])
            else:min=str(T[4])
            print str(T[0])+"-"+str(T[1])+"-"+str(T[2])+" "+str(T[3])+":"+min+": OK!"\
                  ," file:", sensor_file_name, "lines:",len(lines),"counts=", counts, "status=", status

            # ________________________________________check growth of data file
            if len(lines) > len_lines_old:
                time_last_new_lines=time.time()
            else:
                print "Number of lines constant for %.1f" %(time.time()-time_last_new_lines),"s"\
                      ,"limit=",number_of_lines_timeout_seconds,"s."
        
            len_lines_old=len(lines)

        else: 
            print time.asctime(),"Found no file:", sensor_file_name, ". Will try again."

    # ________________________ problem detected; collect info and write log
    try:
        err=file("Lightwatchlog.log","a") # append
        err.write( time.asctime()+":" )
        if counts==0 or status==0:  # log USB-error
            err.write( " File: lines="+str(len(lines)) \
                     + " counts= "+str(counts) \
                     + " status= "+str(status)   \
                     )
            
        if time.time()-time_last_new_lines > number_of_lines_timeout_seconds:
            # numer of lines timeout-logging
            err.write(" File did not grow for:" \
                     +str( int(time.time()-time_last_new_lines) )+ " s."  \
                     )
        err.write(" reboot!\n")
        err.close()
        
    except:
        print "Error-logging failed."
            

except: # General exception to catch all errors (reboot follows)
    try:
        err=file("Lightwatchlog.log","a") # append
        err.write("-------------------> Unknown-error:\n" \
                 + time.asctime()          \
                 + "File:"+str(len(lines)) \
                 + " data-lines; counts= "+str(counts) \
                 + " status = "+str(status)   \
                 + "\n"    \
                 + "Rebooting system.\n"
                 )                                
        err.close()
    except:
        print "Exception; but error-logging failed."

print "Intitiating reboot."
         
os.system("shutdown -r -f")  # r: reboot f: forces shutdown
    
print "Lightwatch: Done"
